# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0] - 2022-04-01
### Added
- Added ability to override the base url for the GitHub API. Good for GitHub enterprise installs.

## [0.1.0] - 2022-04-01
### Added
- Imported my code
- Added build and testing infrastructure
